@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.9) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.4.10) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4/i386-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "9"
-  CONFIG["PATCHLEVEL"] = "362"
-  CONFIG["INSTALL"] = '/pobj/ruby-2.4.9/bin/install -c'
+  CONFIG["TEENY"] = "10"
+  CONFIG["PATCHLEVEL"] = "364"
+  CONFIG["INSTALL"] = '/build/tmp/pobj//ruby-2.4.10/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)24"
@@ -144,9 +144,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/pobj/ruby-2.4.9/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/pobj/ruby-2.4.9/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/pobj/ruby-2.4.9/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/build/tmp/pobj//ruby-2.4.10/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/build/tmp/pobj//ruby-2.4.10/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/build/tmp/pobj//ruby-2.4.10/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -198,7 +198,7 @@ module RbConfig
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "i386"
   CONFIG["build"] = "i386-unknown-openbsd6.6"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.9"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.10"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
