@@ -1,7 +1,8 @@
+# frozen_string_literal: false
 #
 #   shell/command-controller.rb -
 #       $Release Version: 0.7 $
-#       $Revision: 38201 $
+#       $Revision: 67820 $
 #       by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -24,7 +25,6 @@ class Shell
   # Alternatively, you can execute any command via
   # Shell::CommandProcessor#system even if it is not defined.
   class CommandProcessor
-#    include Error
 
     #
     # initialize of Shell and related classes.
@@ -121,11 +121,10 @@ class Shell
           end
           f
         else
-          f = File.open(path, mode, perm, &b)
+          File.open(path, mode, perm, &b)
         end
       end
     end
-    #  public :open
 
     # call-seq:
     #   unlink(path)
@@ -181,6 +180,9 @@ class Shell
             top_level_test(command, file1)
           end
         else
+          unless FileTest.methods(false).include?(command.to_sym)
+            raise "unsupported command: #{ command }"
+          end
           if file2
             FileTest.send(command, file1, file2)
           else
@@ -369,7 +371,12 @@ class Shell
 
       for p in @shell.system_path
         path = join(p, command)
-        if FileTest.exist?(path)
+        begin
+          st = File.stat(path)
+        rescue SystemCallError
+          next
+        else
+          next unless st.executable? and !st.directory?
           @system_commands[command] = path
           return path
         end
@@ -645,7 +652,6 @@ class Shell
         ["mtime", ["FILENAME"]],
         ["readlink", ["FILENAME"]],
         ["rename", ["FILENAME_FROM", "FILENAME_TO"]],
-        #      ["size", ["FILENAME"]],
         ["split", ["pathname"]],
         ["stat", ["FILENAME"]],
         ["symlink", ["FILENAME_O", "FILENAME_N"]],
